==> campsite-2.4.1.tbz: campsite/www-common/html/priv/lang/cz/issues.php <==
<?php
regGS("Issue List", "");
regGS("Name<BR><SMALL>(click to see sections)</SMALL>", "Název publikace");
regGS("Front Page Template<BR><SMALL>(click to change)</SMALL>", "Šablona titulní strany");
regGS("Single Article Template<BR><SMALL>(click to change)</SMALL>", "Šablona článku (klikněte pro změnu)");
regGS("Published<BR><SMALL>(yyyy-mm-dd)</SMALL>", "Zveřejněno (rrrr-mm-dd)");
regGS("Delete issue $1", "Smazat vydání $1");
regGS("Change issue status", "Změnit stav vydání");
regGS("You do not have the right to change issues.", "Nemáte právo měnit vydání");
regGS("Are you sure you want to change the issue $1 status from $2 to $3?", "Určitě chcete změnit stav vydání $1 z $2 na $3?");
regGS("Changing issue status", "Změna stavu vydání");
regGS("Status of the issue $1 has been changed from $2 to $3", "Stav vydání $1 byl změněn z $2 na $3");
regGS("Status of the issue $1 could not be changed.", "Stav vydání $1 nemohl být změněn");
regGS("Add new translation", "Přidat překlad");
regGS("You do not have the right to add issues.", "Nemáte právo přidat vydání");
regGS("The issue $1 has been successfuly added.", "Vydání $1 bylo úspěšně přidáno");
regGS("The issue could not be added.", "Vydání nemohlo být přidáno");
regGS("Please check if another issue with the same number/language does not already exist.", "Zkontrolujte, zda již neexistuje vydání se stejným číslem/jazykem");
regGS("Change issue details", "Změnit detaily vydání");
regGS("You do not have the right to change issue details.", "Nemáte právo změnit detaily vydání");
regGS("Updating issue", "Obnova vydání");
regGS("Changing issue's details", "Změna detailů vydání");
regGS("The issue $1 has been successfuly changed.", "Vydání $1 bylo úspěšně změněno");
regGS("The issue could not be changed.", "Vydání nemohlo být změněno");
regGS("Issue $1 updated in publication $2", "Vydání $1 bylo obnoveno v publikaci $2");
regGS("You do not have the right to delete issues.", "Nemáte právo mazat vydání");
regGS("Are you sure you want to delete the issue $1?", "Určitě chcete smazat vydání $1?");
regGS("Deleting issue", "Mazaní vydání");
regGS("Use the structure of the previous issue", "Použít strukturu předchozího vydání");
regGS("Copy the entire structure in all languages from the previous issue except for content.", "Kopírovat celou strukturu ve všech jazycích z předchozího vydání kromě obsahu");
regGS("You may modify it later if you wish.", "Můžete to upravit později");
regGS("Create a new structure", "Vytvořit novou strukturu");
regGS("Create a complete new structure.", "Vytvořit kopletně novou strukturu");
regGS("You must define an issue type for each language and then sections for them.", "Definovat typ vydání pro každý jazyk a rubriky");
regGS("Copy previous issue", "Kopírovat předchozí vydání");
regGS("No previous issue.", "Žádné předchozí vydání");
regGS("Copy structure from issue nr $1", "Kopírovat strukturu z vydání č. $1");
regGS("Copying previous issue", "Kopírování předchozího vydání");
regGS("Select the issue", "Vyberte vydání");
regGS("New issue $1 from $2 in publication $3", "Nové vydání $1 z $1 v publikaci $3");
regGS("Adding new issue", "Přidání nového vydání");
regGS("Preview issue", "Náhled vydání");
regGS("This issue cannot be previewed. Please make sure it has a $1 template selected.", "Nelze provést náhled tohoto vydání. ");
regGS("front page", "titulní strana");
regGS("Changing issue template", "Změna šablony vydání");
regGS("You do not have the right to change issue templates.", "Nemáte právo měnit šablony vydání");
regGS("Changing issue template for front page", "Změna šablony vydání pro titulní stranu");
regGS("Changing issue template for single article", "Změna šablony vydání pro jednotlivý článek");
regGS("The template has been successfully changed.", "Šablona byla úspěšně změněna");
regGS("Issue template for publication $1 changed to $2", "Šablona vydání pro publikaci $1 byla změněna na $2");
regGS("Issue template for single articles from $1 changed to $2", "Šablona vydání pro jednotlivé články z $1 byla změněna na $2");
regGS("The template could not be changed.", "Šablona namohla být změněna");
?>

==> campsite-2.6.1.tbz: campsite/www-common/html/priv/lang/cz/issues.php <==
<?php 
regGS("Change issue status", "");
regGS("The values you are trying to set conflict with issue \"$1$2. $3 ($4)$5\".", "");
regGS("The number must be unique for each issue in this publication of the same language.", "");
regGS("The language and URL name must be unique for each issue in this publication.", "");
regGS("Issue created.", "");
regGS("Issue updated", "");
regGS("Could not save the changes to the issue.", "");
regGS("Unpublish on: $1", "");
regGS("There are $1 articles in this issue.", "");
regGS("The issue $1 has been deleted.", "");
regGS("Schedule", "");
regGS("Publish on: $1", "");
regGS("Publish Date $1", "");
regGS("Deleted issue", "");
regGS("Delete issue", "");
regGS("Click here to publish this issue", "");
regGS("A total of $1 articles were deleted.", "");
regGS("Name<BR><SMALL>(click to see sections)</SMALL>", "Název publikace");
regGS("Front Page Template<BR><SMALL>(click to change)</SMALL>", "Šablona titulní strany");
regGS("Single Article Template<BR><SMALL>(click to change)</SMALL>", "Šablona článku (klikněte pro změnu)");
regGS("Delete issue $1", "Smazat vydání $1");
regGS("You do not have the right to change issues.", "Nemáte právo měnit vydání");
regGS("Are you sure you want to change the issue $1 status from $2 to $3?", "Určitě chcete změnit stav vydání $1 z $2 na $3?");
regGS("Changing issue status", "Změna stavu vydání");
regGS("Status of the issue $1 has been changed from $2 to $3", "Stav vydání $1 byl změněn z $2 na $3");
regGS("Status of the issue $1 could not be changed.", "Stav vydání $1 nemohl být změněn");
regGS("Add new translation", "Přidat překlad");
regGS("You do not have the right to add issues.", "Nemáte právo přidat vydání");
regGS("The issue $1 has been successfuly added.", "Vydání $1 bylo úspěšně přidáno");
regGS("The issue could not be added.", "Vydání nemohlo být přidáno");
regGS("Change issue details", "Změnit detaily vydání");
regGS("You do not have the right to change issue details.", "Nemáte právo změnit detaily vydání");
regGS("Updating issue", "Obnova vydání");
regGS("Changing issue's details", "Změna detailů vydání");
regGS("The issue $1 has been successfuly changed.", "Vydání $1 bylo úspěšně změněno");
regGS("The issue could not be changed.", "Vydání nemohlo být změněno");
regGS("Issue $1 updated in publication $2", "Vydání $1 bylo obnoveno v publikaci $2");
regGS("You do not have the right to delete issues.", "Nemáte právo mazat vydání");
regGS("Are you sure you want to delete the issue $1?", "Určitě chcete smazat vydání $1?");
regGS("Use the structure of the previous issue", "Použít strukturu předchozího vydání");
regGS("Copy the entire structure in all languages from the previous issue except for content.", "Kopírovat celou strukturu ve všech jazycích z předchozího vydání kromě obsahu");
regGS("You may modify it later if you wish.", "Můžete to upravit později");
regGS("Create a new structure", "Vytvořit novou strukturu");
regGS("Create a complete new structure.", "Vytvořit kopletně novou strukturu");
regGS("You must define an issue type for each language and then sections for them.", "Definovat typ vydání pro každý jazyk a rubriky");
regGS("Copy previous issue", "Kopírovat předchozí vydání");
regGS("No previous issue.", "Žádné předchozí vydání");
regGS("Copy structure from issue number $1", "Kopírovat strukturu z vydání č. $1");
regGS("New issue $1 from $2 in publication $3", "Nové vydání $1 z $1 v publikaci $3");
regGS("Preview issue", "Náhled vydání");
regGS("This issue cannot be previewed. Please make sure it has a $1 template selected.", "Nelze provést náhled tohoto vydání. ");
regGS("front page", "titulní strana");
regGS("Changing issue template", "Změna šablony vydání");
regGS("You do not have the right to change issue templates.", "Nemáte právo měnit šablony vydání");
regGS("Changing issue template for front page", "Změna šablony vydání pro titulní stranu");
regGS("Changing issue template for single article", "Změna šablony vydání pro jednotlivý článek");
regGS("The template has been successfully changed.", "Šablona byla úspěšně změněna");
regGS("Issue template for publication $1 changed to $2", "Šablona vydání pro publikaci $1 byla změněna na $2");
regGS("Issue template for single articles from $1 changed to $2", "Šablona vydání pro jednotlivé články z $1 byla změněna na $2");
regGS("The template could not be changed.", "Šablona namohla být změněna");
regGS("There was an error reading the language parameter.", "");
regGS("There was an error reading the publication parameter.", "");
regGS("There was an error reading the issue parameter.", "");
regGS("There was an error scheduling the $1 action on $2", "Nebylo možné naplánovat činnost $1 na $2");
regGS("The action scheduled on $1 could not be deleted.", "Činnost naplánovaná na $1 nemohla být zrušena");
?>
